#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 random-shuffle
version:              0.0.4
visibility:           public
id:                   random-shuffle-0.0.4-AYeUcVcCXSbArC3cHTDfvo
key:                  random-shuffle-0.0.4-AYeUcVcCXSbArC3cHTDfvo
license:              BSD-3-Clause
copyright:
    Oleg Kiselyov 2001
    Manlio Perillo 2009

maintainer:           Manlio Perillo <manlio.perillo@gmail.com>
author:               Oleg Kiselyov, Manlio Perillo, Andras Slemmer
stability:            Beta
synopsis:             Random shuffle implementation.
description:
    Random shuffle implementation, on immutable lists.
    Based on `perfect shuffle'\'' implementation by Oleg Kiselyov,
    available on http://okmij.org/ftp/Haskell/perfect-shuffle.txt

category:             System
abi:                  8620057107413fcbc01b9a25e9d480ce
exposed:              True
exposed-modules:      System.Random.Shuffle
import-dirs:          /usr/lib/ghc-9.6.6/site-local/random-shuffle-0.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/random-shuffle-0.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/random-shuffle-0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-random-shuffle
hs-libraries:         HSrandom-shuffle-0.0.4-AYeUcVcCXSbArC3cHTDfvo
depends:
    MonadRandom-0.6.2.1-BkIKoEdynG7HsoeBaaLE8a base-4.18.2.1
    random-1.2.1.3-JQ5HMleih0QHEX58PgSIMQ

haddock-interfaces:
    /usr/share/doc/haskell-random-shuffle/html/random-shuffle.haddock

haddock-html:         /usr/share/doc/haskell-random-shuffle/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

